Name:           autofs
Version:        5.0.7
Release:        %mkrel 3
License:        GPLv2+
Summary:        A tool for automatically mounting and unmounting filesystems
Group:          System/Kernel and hardware
URL:            ftp://ftp.kernel.org/pub/linux/daemons/autofs
Source0:        ftp://ftp.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}.tar.bz2
Patch0:		autofs-5.0.6-fix-libtirpc-name-clash.patch
Patch102:       autofs-5.0.6-separate-config-files.patch
Patch103:       autofs-5.0.4-rename-configuration-file.patch
Patch104:	autofs-5.0.7-do-not-install-init.patch
Patch105:	autofs-5.0.7-after-nss-lookup.patch
BuildRequires:  openldap-devel
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  libsasl-devel
BuildRequires:  krb5-devel
BuildRequires:  libxml2-devel
BuildRequires:  tirpc-devel
Conflicts:      autosmb
Requires(post):  rpm-helper >= 0.24.1-1
Requires(preun): rpm-helper >= 0.24.1-1

%description
autofs is a daemon which automatically mounts filesystems when you use
them, and unmounts them later when you are not using them.  This can
include network filesystems, CD-ROMs, floppies, and so forth.

%prep
%setup -q -n %{name}-%{version}
%patch0 -R -p1
%patch102 -p1
%patch103 -p1
%patch104 -p0
%patch105 -p1

%build
autoreconf -f -i
%serverbuild

export CFLAGS="%{optflags} -fPIC"

%configure2_5x \
    --with-mapdir=%{_sysconfdir}/%{name} \
    --with-confdir=%{_sysconfdir}/%{name} \
    --with-sasl=yes \
    --disable-mount-locking \
    --enable-ignore-busy \
    --with-libtirpc \
    --with-systemd

%make DONTSTRIP=1  

mkdir examples
cp samples/ldap* examples
cp samples/autofs.schema examples

rm -f README.gentoo

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/autofs
mkdir -p %{buildroot}%{_mandir}/{man5,man8}
mkdir -p %{buildroot}%{_sysconfdir}

%make install INSTALLROOT=%{buildroot}

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 samples/autofs.service %{buildroot}%{_unitdir}/autofs.service

rm -f %{buildroot}%{_sysconfdir}/init.d/%{name}
rm -f %{buildroot}%{_mandir}/man8/autofs*

cat > README.urpmi <<EOF
Mandriva RPM specific notes

setup
-----
Configuration handling in Mandriva package differs from upstream one on several
points:
- the automounts daemon configuration file is %{_sysconfdir}/autofs/autofs.conf
- the autofs service configuration file is %{_sysconfdir}/sysconfig/autofs

Upgrade
-------
Map files have been moved from %{_sysconfdir} to %{_sysconfdir}/autofs. Upgrade
procedure should handle the change automatically.
LDAP usage has changed between autofs 4 and 5. The LDAP schema used has now to
be configured explicitely in autofs configuration, so as to avoid useless
queries. As this can't be handled by package upgrade procedure, you'll have to
edit your configuration manually. See auto.master(5) for details.

EOF

# tune default configuration
perl -pi -e 's|^BROWSE_MODE="no"|BROWSE_MODE="yes"|' \
    %{buildroot}%{_sysconfdir}/autofs/autofs.conf
perl -pi \
    -e 's|^/misc\t|#/misc\t|;' \
    -e 's|^/net\t|#/net\t|;' \
    %{buildroot}%{_sysconfdir}/autofs/auto.master

%post
%_post_service autofs

%preun
%_preun_service autofs

%files
%doc INSTALL CHANGELOG CREDITS README* examples
%config(noreplace) %{_sysconfdir}/autofs
%config(noreplace) %{_sysconfdir}/sysconfig/autofs
%{_unitdir}/autofs.service
%{_libdir}/%{name}
%{_sbindir}/automount
%{_mandir}/*/*


%changelog
* Mon Sep 03 2012 Alexander Khrukin <akhrukin@mandriva.org> 5.0.7-3mdv2012.0
+ Revision: 816237
- release up
- Bad rpm-helper version

* Tue Aug 28 2012 Alexander Khrukin <akhrukin@mandriva.org> 5.0.7-2
+ Revision: 815895
- release up
- Mandriva not mga

* Mon Jul 18 2011 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.6-2
+ Revision: 690591
- upstream patch for hostname resolution (should fix #63732)

* Fri Jul 01 2011 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.6-1
+ Revision: 688437
- new  version

* Mon May 02 2011 Oden Eriksson <oeriksson@mandriva.com> 5.0.5-5
+ Revision: 662896
- mass rebuild

* Wed Dec 08 2010 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.5-4mdv2011.0
+ Revision: 616239
- update to latest patch level

* Tue Nov 30 2010 Oden Eriksson <oeriksson@mandriva.com> 5.0.5-3mdv2011.0
+ Revision: 603481
- rebuild

* Mon Mar 15 2010 Oden Eriksson <oeriksson@mandriva.com> 5.0.5-2mdv2010.1
+ Revision: 520011
- rebuilt for 2010.1

* Thu Sep 10 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.5-1mdv2010.0
+ Revision: 437529
- new version

* Sat Jul 18 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-9mdv2010.0
+ Revision: 397062
- update to latest patchlevel

* Sat May 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-8mdv2010.0
+ Revision: 373838
- update to latest patch level

* Fri Apr 10 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-7mdv2009.1
+ Revision: 365743
-update to latest patch level
-honor USE_MISC_DEVICE setting in initscript

* Sat Mar 14 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-6mdv2009.1
+ Revision: 354885
- update to latest official patch level

* Mon Mar 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-5mdv2009.1
+ Revision: 353183
- update to latest official patch level
- apply custom patches after official ones, to keep them verbatim
- tune configuration through substitutions rather than patches

* Tue Mar 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-4mdv2009.1
+ Revision: 347905
- update to latest official patch level

* Sun Feb 01 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-3mdv2009.1
+ Revision: 336233
- re-enable kerberos lib flag, otherwise ldap plugin doesn't work
- fix segfault when looking for host (#47423)

* Fri Jan 30 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-2mdv2009.1
+ Revision: 335551
- drop sasl detection patch, uneeded anymore
- drop ldap detection patch, available upstream
- update to latest upstream patch level

* Wed Dec 03 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-1mdv2009.1
+ Revision: 309829
- new version
- rediff configuration files separation patch
- drop merged patches

* Tue Sep 09 2008 Olivier Thauvin <nanardon@mandriva.org> 5.0.3-7mdv2009.0
+ Revision: 282880
- convert requires kernel... to conflicts, then avoiding to require kernel in virtual system

* Wed Jul 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.3-6mdv2009.0
+ Revision: 230676
- no dependency on nfs-utils in package (automount is not nfs-specific)
- no dependency on nfs-common in initscript (automound doesn't requires it)
- update to latest official patch set
- fix init script dependencies

* Tue May 20 2008 Stefan van der Eijk <stefan@mandriva.org> 5.0.3-5mdv2009.0
+ Revision: 209577
- rebuild, give it annother shot...
- sync patches to fix expire issue

* Fri Jan 25 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.3-4mdv2008.1
+ Revision: 158131
- sync with latest upstream patches (fix #37107)

  + Olivier Blin <blino@mandriva.org>
    - update to new upstream version of basedn-with-spaces fix

* Mon Jan 21 2008 Olivier Blin <blino@mandriva.org> 5.0.3-2mdv2008.1
+ Revision: 155518
- fix parsing mount options with LDAP mounts (upstream patch)

* Tue Jan 15 2008 Olivier Blin <blino@mandriva.org> 5.0.3-1mdv2008.1
+ Revision: 152545
- workaround upstream ldap-page-control check by adding -lpthread
- add upstream ldap-page-control-configure-fix patch
- rediff comment-default-master-map patch
- 5.0.3
- remove upstream 5.0.2 patches
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-10mdv2008.1
+ Revision: 109442
- fix kerberos linking, and re-enable sasl support
- patch45: fix build without sasl

* Mon Nov 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-9mdv2008.1
+ Revision: 108335
- add libxml2-devel build dependency, but disable sasl build for now, as it breaks ldap module, and is known to be non-functional anyway
- add available upstream patches

* Tue Oct 09 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-8mdv2008.1
+ Revision: 96243
- soft dependency on ypbind in init script

* Mon Oct 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-7mdv2008.0
+ Revision: 94155
- don't deal with /etc/modules.conf, this file isn't used anymore

* Sat Sep 15 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-6mdv2008.0
+ Revision: 86323
- add a reference to README.urpmi in configuration files comments
- don't ship upstream init script man page
- more explicit description of differences with upstream configuration
- patch 103: ensure configuration file remains /etc/autofs/autofs.conf

* Tue Sep 11 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-5mdv2008.0
+ Revision: 84307
- re-enable sasl build

* Mon Sep 10 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-4mdv2008.0
+ Revision: 84274
- update to latest upstream patch set
- fix configuration file name to autofs.conf
- disable sasl support, as it doesn't build

* Mon Jul 30 2007 Andreas Hasenack <andreas@mandriva.com> 5.0.2-3mdv2008.0
+ Revision: 56585
- added digital signature for tarball
- really enable sasl build (we already buildrequire it)

* Thu Jul 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-2mdv2008.0
+ Revision: 53710
- build requires sasl-devel
- set default browse mode to reduce cpu usage (fix #31901)

* Thu Jul 05 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-1mdv2008.0
+ Revision: 48725
- new version
  drop patches 100, 101, 102 and 104 (merged upstream)
  rediff patch 102

* Wed Jul 04 2007 Andreas Hasenack <andreas@mandriva.com> 5.0.1-6mdv2008.0
+ Revision: 48210
- rebuild with new serverbuild macro (-fstack-protector-all)
- autoconf-2.5x is gone, use plain autoconf

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 5.0.1-5mdv2008.0
+ Revision: 36155
- rebuild with correct optflags

